@@ -1,4 +1,4 @@
-/* $Id: gucharmap-charmap.c,v 1.52 2006/01/27 22:33:43 behdad Exp $ */
+/* $Id: gucharmap-charmap.c 1300 2007-01-19 18:32:05Z chpe $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -31,7 +31,7 @@
 #include "gucharmap-marshal.h"
 #include "chartable_accessible.h"
 
-extern gboolean _gucharmap_unicode_has_nameslist_entry (gunichar uc);
+gboolean _gucharmap_unicode_has_nameslist_entry (gunichar uc);
 
 enum 
 {
@@ -67,17 +67,19 @@ gucharmap_charmap_class_init (GucharmapCharmapClass *clazz)
       g_signal_new ("status-message", gucharmap_charmap_get_type (), 
                     G_SIGNAL_RUN_FIRST,
                     G_STRUCT_OFFSET (GucharmapCharmapClass, status_message),
-                    NULL, NULL, gucharmap_marshal_VOID__STRING, G_TYPE_NONE, 
+                    NULL, NULL, _gucharmap_marshal_VOID__STRING, G_TYPE_NONE, 
                     1, G_TYPE_STRING);
 
   gucharmap_charmap_signals[LINK_CLICKED] =
       g_signal_new ("link-clicked", gucharmap_charmap_get_type (), 
                     G_SIGNAL_RUN_FIRST,
                     G_STRUCT_OFFSET (GucharmapCharmapClass, link_clicked),
-                    NULL, NULL, gucharmap_marshal_VOID__UINT_UINT, G_TYPE_NONE, 
+                    NULL, NULL, _gucharmap_marshal_VOID__UINT_UINT, G_TYPE_NONE, 
                     2, G_TYPE_UINT, G_TYPE_UINT);
 
   G_OBJECT_CLASS (clazz)->finalize = charmap_finalize;
+
+  _gucharmap_intl_ensure_initialized ();
 }
 
 static void
