@@ -1,4 +1,4 @@
-/* $Id: gucharmap-search-dialog.c,v 1.25 2006/07/24 23:06:31 behdad Exp $ */
+/* $Id: gucharmap-search-dialog.c 1300 2007-01-19 18:32:05Z chpe $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -29,7 +29,7 @@
 
 #define GUCHARMAP_SEARCH_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), gucharmap_search_dialog_get_type (), GucharmapSearchDialogPrivate))
 
-extern GdkCursor * _gucharmap_window_progress_cursor ();
+GdkCursor * _gucharmap_window_progress_cursor ();
 
 enum
 {
@@ -708,7 +708,7 @@ entry_changed (GtkObject             *object,
 {
   GucharmapSearchDialogPrivate *priv = GUCHARMAP_SEARCH_DIALOG_GET_PRIVATE (search_dialog);
 
-  if (_entry_is_empty(priv->entry))
+  if (_entry_is_empty (GTK_ENTRY (priv->entry)))
     {
       gtk_widget_set_sensitive (priv->prev_button, FALSE);
       gtk_widget_set_sensitive (priv->next_button, FALSE);
