@@ -1,4 +1,4 @@
-/* $Id: gucharmap-window.c,v 1.69 2006/02/13 21:46:46 behdad Exp $ */
+/* $Id: gucharmap-window.c 1300 2007-01-19 18:32:05Z chpe $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -63,8 +63,6 @@ struct _GucharmapWindowPrivate
 
   GtkActionGroup *action_group;
 
-  GdkPixbuf *icon;
-
   GtkWidget *search_dialog; /* takes care of all aspects of searching */
 
   GtkWidget *progress;
@@ -76,6 +74,8 @@ struct _GucharmapWindowPrivate
   ChaptersMode chapters_mode; 
 };
 
+GdkCursor * _gucharmap_window_progress_cursor (void);
+
 static GtkWindowClass *parent_class = NULL;
 
 static void
@@ -160,8 +160,8 @@ _gucharmap_window_progress_cursor (void)
 
   gdkcursor = gdk_cursor_new_from_pixmap (cursor, mask, &fg, &bg, 2, 2);
 
-  gdk_bitmap_unref (cursor);
-  gdk_bitmap_unref (mask);
+  g_object_unref (cursor);
+  g_object_unref (mask);
 
   return gdkcursor;
 }
@@ -318,17 +318,14 @@ static void
 help_about (GtkAction       *action, 
             GucharmapWindow *guw)
 {
-  GucharmapWindowPrivate *priv = GUCHARMAP_WINDOW_GET_PRIVATE (guw);
-  const gchar *translator_credits;
-  const gchar *license_trans;
-
-  const gchar *authors[] = 
+  const gchar *authors[] =
     { 
       "Noah Levitt <nlevitt@columbia.edu>", 
       "Daniel Elstner <daniel.elstner@gmx.net>", 
       "Padraig O'Briain <Padraig.Obriain@sun.com>",
       NULL 
     };
+
   const gchar *documenters[] =
     {
       "Chee Bin HOH <cbhoh@gnome.org>",
@@ -356,25 +353,22 @@ help_about (GtkAction       *action,
        "with Gucharmap; you can always find it at Unicode's website: "
        "http://www.unicode.org/copyright.html")
   };
+  gchar *license_trans;
   license_trans = g_strconcat (_(license[0]), "\n\n", _(license[1]), "\n\n",
 			       _(license[2]), "\n\n", _(license[3]), "\n\n",
 			       _(license[4]), "\n\n", NULL);
 
-  translator_credits = _("translator-credits");
-  if (strcmp (translator_credits, "translator-credits") == 0)
-    translator_credits = NULL;
-
   gtk_show_about_dialog (GTK_WINDOW (guw),
   			 "authors", authors,
 			 "comments", _("GNOME Character Map\n"
-				       "based on Unicode Character Database"),
+				       "based on the Unicode Character Database"),
 			 "copyright", "Copyright © 2004 Noah Levitt <nlevitt@columbia.edu>\n"
 				      "Copyright © 1991-2005 Unicode, Inc.",
 			 "documenters", documenters,
 			 "license", license_trans,
-			 "logo", priv->icon,
 			 "name", _("Gucharmap"),
-			 "translator-credits", translator_credits,
+			 "logo-icon-name", "gucharmap",
+			 "translator-credits", _("translator-credits"),
 			 "version", VERSION,
 			 "website", "http://live.gnome.org/Gucharmap",
 			 "wrap-license", TRUE,
@@ -471,12 +465,12 @@ view_by (GtkAction        *action,
     {
       case VIEW_BY_SCRIPT:
       	gucharmap_charmap_set_chapters (guw->charmap, GUCHARMAP_CHAPTERS (gucharmap_script_chapters_new ()));
-	chapters_set_labels ("Next Script", "Previous Script", guw);
+	chapters_set_labels (_("Next Script"), _("Previous Script"), guw);
 	break;
       
       case VIEW_BY_BLOCK:
         gucharmap_charmap_set_chapters (guw->charmap, GUCHARMAP_CHAPTERS (gucharmap_block_chapters_new ()));
-	chapters_set_labels ("Next Block", "Previous Block", guw);
+	chapters_set_labels (_("Next Block"), _("Previous Block"), guw);
 	break;
       
       default:
@@ -597,7 +591,7 @@ make_menu (GucharmapWindow *guw)
   g_object_unref (priv->accel_group);
 
   toggle_menu = gtk_toggle_action_new ( "SnapColumns",
-					"Snap Columns to Power of Two",
+					_("Snap Columns to Power of Two"),
 					NULL,
 					NULL);
   g_signal_connect (G_OBJECT(toggle_menu), "toggled", G_CALLBACK (snap_cols_pow2), guw);
@@ -630,7 +624,7 @@ make_menu (GucharmapWindow *guw)
 	break;
       
       case CHAPTERS_BLOCK:
-        chapters_set_labels ("Next Block", "Previous Block", guw);
+        chapters_set_labels (_("Next Block"), _("Previous Block"), guw);
 	break;
       
       default:
@@ -756,38 +750,6 @@ make_text_to_copy (GucharmapWindow *guw)
   return hbox;
 }
 
-static void
-load_icon (GucharmapWindow *guw)
-{
-  GucharmapWindowPrivate *priv = GUCHARMAP_WINDOW_GET_PRIVATE (guw);
-  GError *error = NULL;
-
-#ifdef G_OS_WIN32
-
-  gchar *package_root, *icon_path;
-
-  package_root = g_win32_get_package_installation_directory (NULL, NULL);
-  icon_path = g_build_filename (package_root, "share", "icons", "hicolor", "48x48", "apps", "gucharmap.png");
-  priv->icon = gdk_pixbuf_new_from_file (icon_path, &error);
-  g_free (package_root);
-  g_free (icon_path);
-
-#else  /* #ifdef G_OS_WIN32 */
-
-  priv->icon = gdk_pixbuf_new_from_file (ICON_PATH, &error);
-
-#endif /* #ifdef G_OS_WIN32 */
-
-  if (error != NULL)
-    {
-      g_assert (priv->icon == NULL);
-      g_warning ("Error loading icon: %s\n", error->message);
-      g_error_free (error);
-    }
-  else
-    gtk_window_set_icon (GTK_WINDOW (guw), priv->icon);
-}
-
 static void
 status_realize (GtkWidget       *status,
                 GucharmapWindow *guw)
@@ -881,8 +843,7 @@ gucharmap_window_init (GucharmapWindow *guw)
 
   priv->search_dialog = NULL;
 
-  load_icon (guw);
-  gtk_window_set_icon (GTK_WINDOW (guw), priv->icon);
+  gtk_window_set_icon_name (GTK_WINDOW (guw), "gucharmap");
 
   pack_stuff_in_window (guw);
 }
@@ -916,7 +877,7 @@ gucharmap_window_class_init (GucharmapWindowClass *clazz)
   G_OBJECT_CLASS (clazz)->finalize = window_finalize;
   g_type_class_add_private (clazz, sizeof (GucharmapWindowPrivate));
 
-  gucharmap_intl_ensure_initialized ();
+  _gucharmap_intl_ensure_initialized ();
 }
 
 GType 
